from a10sdk.common.A10BaseClass import A10BaseClass


class Bfd(A10BaseClass):
    
    """Class Description::
    Bidirectional Forwarding Detection.

    Class bfd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param local_ip: {"optional": false, "type": "string", "description": "Local IP address", "format": "ipv4-address"}
    :param nexthop_ip: {"optional": false, "type": "string", "description": "Nexthop IP address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/route/static/bfd/{local_ip}+{nexthop_ip}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "local_ip","nexthop_ip"]

        self.b_key = "bfd"
        self.a10_url="/axapi/v3/ip/route/static/bfd/{local_ip}+{nexthop_ip}"
        self.DeviceProxy = ""
        self.local_ip = ""
        self.nexthop_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DevVipPortList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_port_num: {"type": "number", "format": "number"}
    :param dev_vip_port_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dev-vip-port-list"
        self.DeviceProxy = ""
        self.dev_vip_port_num = ""
        self.dev_vip_port_state = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dev_vip_addr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param dev_vip_port_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dev-vip-port-num": {"type": "number", "format": "number"}, "dev-vip-port-state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.dev_vip_addr = ""
        self.dev_vip_state = ""
        self.dev_vip_port_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VipServerV6(A10BaseClass):
    
    """Class Description::
    Operational Status for the object vip-server-v6.

    Class vip-server-v6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6: {"optional": false, "oid": "1001", "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server/vip-server-v6/{ipv6}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vip-server-v6"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server/vip-server-v6/{ipv6}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class KerberosSpn(A10BaseClass):
    
    """Class Description::
    AD domain account associated with a SPN.

    Class kerberos-spn supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param account: {"description": "Specify domain account for SPN", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param realm: {"description": "Specify Kerberos realm", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param name: {"description": "Specify AD account name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.)", "format": "encrypted"}
    :param password: {"default": 0, "optional": true, "type": "number", "description": "Specify password of domain account", "format": "flag"}
    :param service_principal_name: {"description": "Specify service principal name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param secret_string: {"description": "Password of AD account", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/account/kerberos-spn/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "kerberos-spn"
        self.a10_url="/axapi/v3/aam/authentication/account/kerberos-spn/{name}"
        self.DeviceProxy = ""
        self.account = ""
        self.realm = ""
        self.name = ""
        self.encrypted = ""
        self.password = ""
        self.service_principal_name = ""
        self.secret_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Bind(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tunnel: {"description": "Tunnel interface index", "format": "number", "maximum": 128, "minimum": 1, "type": "number", "$ref": "/axapi/v3/interface/tunnel"}
    :param next_hop: {"type": "string", "description": "IPsec Next Hop IP Address", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "bind"
        self.DeviceProxy = ""
        self.tunnel = ""
        self.next_hop = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param remote: {"type": "string", "description": "IPv4 Address", "format": "ipv4-address"}
    :param local_protocol: {"description": "IP Protocol Number (0-255)", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}
    :param local_port: {"description": "Port Number", "minimum": 0, "type": "number", "maximum": 65535, "format": "number"}
    :param remote_port: {"description": "Port Number", "minimum": 0, "type": "number", "maximum": 65535, "format": "number"}
    :param local_netmask: {"type": "string", "description": "IPv4 Address Network Mask", "format": "ipv4-netmask"}
    :param remote_netmask: {"type": "string", "description": "IPv4 Address Network Mask", "format": "ipv4-netmask"}
    :param remote_protocol: {"description": "IP Protocol Number (0-255)", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}
    :param local: {"type": "string", "description": "Local Traffic Selector", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv4"
        self.DeviceProxy = ""
        self.remote = ""
        self.local_protocol = ""
        self.local_port = ""
        self.remote_port = ""
        self.local_netmask = ""
        self.remote_netmask = ""
        self.remote_protocol = ""
        self.local = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TrafficSelector(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "traffic-selector"
        self.DeviceProxy = ""
        self.ipv4 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class EncCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}
    :param encryption: {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}
    :param hash: {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "enc-cfg"
        self.DeviceProxy = ""
        self.priority = ""
        self.encryption = ""
        self.A10WW_hash = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipsec(A10BaseClass):
    
    """Class Description::
    IPsec settings.

    Class ipsec supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param lifebytes: {"description": "IPsec SA age in megabytes", "format": "number", "default": 0, "optional": true, "maximum": 8000000, "minimum": 0, "type": "number"}
    :param ike_gateway: {"description": "Gateway to use for IPsec SA", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/vpn/ike-gateway"}
    :param name: {"description": "IPsec name", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param dh_group: {"optional": true, "enum": ["0", "1", "2", "5", "14", "15", "16", "18"], "type": "string", "description": "'0': Diffie-Hellman group 0 (Default); '1': Diffie-Hellman group 1; '2': Diffie-Hellman group 2; '5': Diffie-Hellman group 5; '14': Diffie-Hellman group 14; '15': Diffie-Hellman group 15; '16': Diffie-Hellman group 16; '18': Diffie-Hellman group 18; ", "format": "enum"}
    :param proto: {"description": "'esp': Encapsulating security protocol (Default); ", "format": "enum", "default": "esp", "type": "string", "enum": ["esp"], "optional": true}
    :param up: {"default": 0, "optional": true, "type": "number", "description": "Initiates SA negotiation to bring the IPsec connection up", "format": "flag"}
    :param anti_replay_window: {"optional": true, "enum": ["0", "16", "32", "64", "128", "256"], "type": "string", "description": "'0': Disable Anti-Replay Window Check; '16': Window Size of 16 bits; '32': Window Size of 32 bits; '64': Window Size of 64 bits; '128': Window Size of 128 bits; '256': Window Size of 256 bits; ", "format": "enum"}
    :param mode: {"description": "'tunnel': Encapsulating the packet in IPsec tunnel mode (Default); ", "format": "enum", "default": "tunnel", "type": "string", "enum": ["tunnel"], "optional": true}
    :param lifetime: {"description": "IPsec SA age in seconds", "format": "number", "default": 28800, "optional": true, "maximum": 28800, "minimum": 30, "type": "number"}
    :param enc_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Prioritizes (1-10) security protocol, least value has highest priority", "format": "number", "default": 5, "maximum": 10, "minimum": 1, "type": "number"}, "encryption": {"enum": ["des", "3des", "aes-128", "aes-192", "aes-256", "null"], "type": "string", "description": "'des': Data Encryption Standard algorithm; '3des': Triple Data Encryption Standard algorithm; 'aes-128': Advanced Encryption Standard algorithm (key size: 128 bits); 'aes-192': Advanced Encryption Standard algorithm (key size: 192 bits); 'aes-256': Advanced Encryption Standard algorithm (key size: 256 bits); 'null': No encryption algorithm; ", "format": "enum"}, "hash": {"enum": ["md5", "sha1", "sha256", "null"], "type": "string", "description": "'md5': MD5 Dessage-Digest Algorithm; 'sha1': Secure Hash Algorithm 1; 'sha256': Secure Hash Algorithm 256; 'null': No hash algorithm; ", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vpn/ipsec/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "ipsec"
        self.a10_url="/axapi/v3/vpn/ipsec/{name}"
        self.DeviceProxy = ""
        self.lifebytes = ""
        self.ike_gateway = ""
        self.name = ""
        self.dh_group = ""
        self.proto = ""
        self.bind = {}
        self.up = ""
        self.anti_replay_window = ""
        self.traffic_selector = {}
        self.mode = ""
        self.lifetime = ""
        self.enc_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param username: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Specify the username", "format": "string"}
    :param monitor: {"default": 0, "type": "number", "description": "Specify monitor TACACS+ server", "format": "flag"}
    :param encrypted: {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}
    :param timeout: {"description": "Specify the maximum time allowed for setting up a connection with the TACACS+ server. (default timeout is 12 seconds) (Maximum time allowed for setting up a connection with the TACACS+ server, in seconds (default 12))", "format": "number", "default": 12, "maximum": 12, "minimum": 1, "type": "number"}
    :param password_value: {"minLength": 1, "maxLength": 31, "type": "string", "description": "The user password", "format": "password"}
    :param password: {"default": 0, "type": "number", "description": "Specify the user password", "format": "flag"}
    :param port: {"description": "Specify the port number used by TACACS+ server.( default port is 49) (Port number (default 49))", "format": "number", "default": 49, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-cfg"
        self.DeviceProxy = ""
        self.username = ""
        self.monitor = ""
        self.encrypted = ""
        self.timeout = ""
        self.password_value = ""
        self.password = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Secret(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param encrypted: {"minLength": 1, "maxLength": 255, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) help-val The ENCRYPTED secret string", "format": "encrypted"}
    :param secret_value: {"minLength": 1, "maxLength": 127, "type": "string", "description": "The TACACS+ server's secret", "format": "password"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "secret"
        self.DeviceProxy = ""
        self.port_cfg = {}
        self.encrypted = ""
        self.secret_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4(A10BaseClass):
    
    """Class Description::
    Specify the hostname of TACACS+ server.

    Class ipv4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv4_addr: {"optional": false, "type": "string", "description": "IPV4 address of TACACS+ server", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/tacacs-server/host/ipv4/{ipv4_addr}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv4_addr"]

        self.b_key = "ipv4"
        self.a10_url="/axapi/v3/tacacs-server/host/ipv4/{ipv4_addr}"
        self.DeviceProxy = ""
        self.ipv4_addr = ""
        self.secret = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SynCookie(A10BaseClass):
    
    """Class Description::
    Global Syn-Cookie Protection.

    Class syn-cookie supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param on_threshold: {"description": "on-threshold for Syn-cookie (Decimal number)", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param enable: {"default": 0, "optional": true, "type": "number", "description": "Global Syn-Cookie Protection", "format": "flag"}
    :param off_threshold: {"description": "off-threshold for Syn-cookie (Decimal number)", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 0, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/syn-cookie`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "syn-cookie"
        self.a10_url="/axapi/v3/syn-cookie"
        self.DeviceProxy = ""
        self.on_threshold = ""
        self.enable = ""
        self.off_threshold = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocationMatch(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geo_location: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Geolocation name", "format": "string"}
    :param geo_location_service_group: {"description": "Service Group to be used (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param geo_location_template: {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}
    :param geo_location_template_name: {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geo-location-match"
        self.DeviceProxy = ""
        self.geo_location = ""
        self.geo_location_service_group = ""
        self.geo_location_template = ""
        self.geo_location_template_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HttpPolicyMatch(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param match_string: {"minLength": 1, "maxLength": 128, "type": "string", "description": "URL String", "format": "string-rlx"}
    :param template_name: {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}
    :param service_group: {"description": "Service Group to be used (Service Group Name)", "format": "string", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}
    :param template: {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}
    :param type: {"enum": ["cookie", "host", "url"], "type": "string", "description": "'cookie': cookie value match; 'host': hostname match; 'url': URL match; ", "format": "enum"}
    :param match_type: {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "http-policy-match"
        self.DeviceProxy = ""
        self.match_string = ""
        self.template_name = ""
        self.service_group = ""
        self.template = ""
        self.A10WW_type = ""
        self.match_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HttpPolicy(A10BaseClass):
    
    """Class Description::
    http-policy template.

    Class http-policy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param geo_location_match: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"geo-location": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Geolocation name", "format": "string"}, "geo-location-service-group": {"description": "Service Group to be used (Service Group Name)", "format": "string-rlx", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "optional": true, "geo-location-template": {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}, "geo-location-template-name": {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}}}]}
    :param name: {"description": "http-policy template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param http_policy_match: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "match-string": {"minLength": 1, "maxLength": 128, "type": "string", "description": "URL String", "format": "string-rlx"}, "template-name": {"description": "WAF template to be used (Template Name)", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/waf/template"}, "service-group": {"description": "Service Group to be used (Service Group Name)", "format": "string", "minLength": 1, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/slb/service-group"}, "template": {"enum": ["waf"], "type": "string", "description": "'waf': waf;  (WAF template to be used)", "format": "enum"}, "type": {"enum": ["cookie", "host", "url"], "type": "string", "description": "'cookie': cookie value match; 'host': hostname match; 'url': URL match; ", "format": "enum"}, "match-type": {"enum": ["contains", "ends-with", "equals", "starts-with"], "type": "string", "description": "'contains': Select service group if URL string contains another string; 'ends-with': Select service group if URL string ends with another string; 'equals': Select service group if URL string equals another string; 'starts-with': Select service group if URL string starts with another string; ", "format": "enum"}}}]}
    :param cookie_name: {"description": "name of cookie to match (Cookie Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/http-policy/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "http-policy"
        self.a10_url="/axapi/v3/slb/template/http-policy/{name}"
        self.DeviceProxy = ""
        self.geo_location_match = []
        self.name = ""
        self.http_policy_match = []
        self.cookie_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VipServer(A10BaseClass):
    
    """Class Description::
    Specify a VIP for the SLB device.

    Class vip-server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vip_server_v4_list: {"minItems": 1, "items": {"type": "vip-server-v4"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"ipv4": {"optional": false, "type": "string", "description": "Specify IP address", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v4/{ipv4}"}
    :param vip_server_v6_list: {"minItems": 1, "items": {"type": "vip-server-v6"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"ipv6": {"optional": false, "type": "string", "description": "Specify IP address (IPv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-v6/{ipv6}"}
    :param vip_server_name_list: {"minItems": 1, "items": {"type": "vip-server-name"}, "uniqueItems": true, "array": [{"required": ["vip-name"], "properties": {"vip-name": {"description": "Specify a VIP name for the SLB device", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/service-ip"}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/slb-dev/{device-name}/vip-server/vip-server-name/{vip-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vip-server"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/slb-dev/{device_name}/vip-server"
        self.DeviceProxy = ""
        self.vip_server_v4_list = []
        self.vip_server_v6_list = []
        self.vip_server_name_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ActiveRdt(A10BaseClass):
    
    """Class Description::
    Active RDT Options for SLB device.

    Class active-rdt supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param domain: {"description": "Specify Query Domain (Specify Domain Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param retry: {"description": "Specify Retry Count, default is 3", "format": "number", "default": 3, "optional": true, "maximum": 16, "minimum": 0, "type": "number"}
    :param track: {"description": "Specify Tracking Time, unit: second, default is 60", "format": "number", "default": 60, "optional": true, "maximum": 16383, "minimum": 3, "type": "number"}
    :param interval: {"description": "Specify Query Interval, unit: second, default is 1", "format": "number", "default": 1, "optional": true, "maximum": 16383, "minimum": 1, "type": "number"}
    :param sleep: {"description": "Specify Sleep Time when query fail, unit: second, default is 3", "format": "number", "default": 3, "optional": true, "maximum": 300, "minimum": 1, "type": "number"}
    :param timeout: {"description": "Specify Query Timeout, unit: msec, default is 3000", "format": "number", "default": 3000, "optional": true, "maximum": 16383, "minimum": 1, "type": "number"}
    :param port: {"description": "Specify local port to send probe packet, default is 0 (no port)", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/active-rdt`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "active-rdt"
        self.a10_url="/axapi/v3/gslb/active-rdt"
        self.DeviceProxy = ""
        self.domain = ""
        self.retry = ""
        self.track = ""
        self.interval = ""
        self.sleep = ""
        self.timeout = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param giants: {"description": "Giants", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param transmitted_multicasts: {"description": "Transmitted multicasts", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param received_broadcasts: {"description": "Received broadcasts", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param received_multicasts: {"description": "Received multicasts", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param packets_input: {"description": "Input packets", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param transmitted_unicasts: {"description": "Transmitted unicasts", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param crc: {"description": "CRC", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param packets_output: {"description": "Output packets", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param received_unicasts: {"description": "Received unicasts", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param runts: {"description": "Runts", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param bytes_output: {"description": "Output bytes", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param collisions: {"description": "Collisions", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param input_errors: {"description": "Input errors", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param bytes_input: {"description": "Input bytes", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param transmitted_broadcasts: {"description": "Transmitted braodcasts", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param frame: {"description": "Frames", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param output_errors: {"description": "Output errors", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.giants = ""
        self.transmitted_multicasts = ""
        self.received_broadcasts = ""
        self.received_multicasts = ""
        self.packets_input = ""
        self.transmitted_unicasts = ""
        self.crc = ""
        self.packets_output = ""
        self.received_unicasts = ""
        self.runts = ""
        self.bytes_output = ""
        self.collisions = ""
        self.input_errors = ""
        self.bytes_input = ""
        self.transmitted_broadcasts = ""
        self.frame = ""
        self.output_errors = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ethernet(A10BaseClass):
    
    """Class Description::
    Statistics for the object ethernet.

    Class ethernet supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param trunk_group_list: {"minItems": 1, "items": {"type": "trunk-group"}, "uniqueItems": true, "array": [{"required": ["trunk-number"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/interface/ethernet/{ifnum}/lldp/ddos/ip/ipv6/lw-4o6/trunk-group/{trunk-number}"}
    :param ifnum: {"optional": false, "oid": "1001", "type": "number", "description": "Ethernet interface number", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ethernet/{ifnum}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "ethernet"
        self.a10_url="/axapi/v3/interface/ethernet/{ifnum}/stats"
        self.DeviceProxy = ""
        self.lldp = {}
        self.stats = {}
        self.bfd = {}
        self.ip = {}
        self.ddos = {}
        self.trunk_group_list = []
        self.ifnum = ""
        self.lw_4o6 = {}
        self.ipv6 = {}
        self.isis = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class User(A10BaseClass):
    
    """Class Description::
    Define a user who can access the SNMP engine.

    Class user supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param username: {"description": "Name of the user", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param auth_val: {"optional": true, "enum": ["md5", "sha"], "type": "string", "description": "'md5': Use HMAC MD5 algorithm for authentication; 'sha': Use HMAC SHA algorithm for authentication; ", "format": "enum"}
    :param group: {"description": "Group to which the user belongs", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param encpasswd: {"description": "Passphrase for encryption", "format": "password", "minLength": 8, "optional": true, "maxLength": 31, "type": "string"}
    :param passwd: {"description": "Password of this user", "format": "password", "minLength": 8, "optional": true, "maxLength": 31, "type": "string"}
    :param priv_pw_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED passphrase string)", "format": "encrypted"}
    :param v3: {"optional": true, "enum": ["auth", "noauth"], "type": "string", "description": "'auth': Using the authNoPriv Security Level; 'noauth': Using the noAuthNoPriv Security Level; ", "format": "enum"}
    :param pw_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED passphrase string)", "format": "encrypted"}
    :param priv: {"optional": true, "enum": ["des", "aes"], "type": "string", "description": "'des': DES encryption alogrithm; 'aes': AES encryption alogrithm;  (Encryption type)", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/user/{username}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "username"]

        self.b_key = "user"
        self.a10_url="/axapi/v3/snmp-server/user/{username}"
        self.DeviceProxy = ""
        self.username = ""
        self.auth_val = ""
        self.group = ""
        self.encpasswd = ""
        self.passwd = ""
        self.priv_pw_encrypted = ""
        self.v3 = ""
        self.pw_encrypted = ""
        self.priv = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param method_options: {"description": "SIP Method OPTIONS", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param method_invite: {"description": "SIP Method INVITE", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param method_publish: {"description": "SIP Method PUBLISH", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param method_unknown: {"description": "SIP Method UNKNOWN", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param method_update: {"description": "SIP Method UPDATE", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param method_subscribe: {"description": "SIP Method SUBSCRIBE", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param method_register: {"description": "SIP Method REGISTER", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param method_prack: {"description": "SIP Method PRACK", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param method_notify: {"description": "SIP Method NOTIFY", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param method_info: {"description": "SIP Method INFO", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param method_ack: {"description": "SIP Method ACK", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param method_refer: {"description": "SIP Method REFER", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param method_message: {"description": "SIP Method MESSAGE", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param method_bye: {"description": "SIP Method BYE", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param method_cancel: {"description": "SIP Method CANCEL", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.method_options = ""
        self.method_invite = ""
        self.method_publish = ""
        self.method_unknown = ""
        self.method_update = ""
        self.method_subscribe = ""
        self.method_register = ""
        self.method_prack = ""
        self.method_notify = ""
        self.method_info = ""
        self.method_ack = ""
        self.method_refer = ""
        self.method_message = ""
        self.method_bye = ""
        self.method_cancel = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Sip(A10BaseClass):
    
    """Class Description::
    Statistics for the object sip.

    Class sip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/fixed-nat/alg/sip/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sip"
        self.a10_url="/axapi/v3/cgnv6/fixed-nat/alg/sip/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class CookieDomain(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cookie_dmn: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify domain scope for the authentication (ex: .a10networks.com)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cookie-domain"
        self.DeviceProxy = ""
        self.cookie_dmn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CookieDomainGroup(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cookie_dmngrp: {"description": "Specify group id to join in the cookie-domain", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cookie-domain-group"
        self.DeviceProxy = ""
        self.cookie_dmngrp = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Template(A10BaseClass):
    
    """Class Description::
    Authentication template.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param logout_idle_timeout: {"description": "Specify idle logout time (Specify idle timeout in seconds, default is 300)", "format": "number", "default": 300, "optional": true, "maximum": 86400, "minimum": 1, "type": "number"}
    :param cookie_domain: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmn": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify domain scope for the authentication (ex: .a10networks.com)", "format": "string-rlx"}, "optional": true}}]}
    :param name: {"description": "Authentication template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param relay: {"description": "Specify authentication relay (Specify authentication relay template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/relay/http-basic/instance"}
    :param logon: {"description": "Specify authentication logon (Specify authentication logon template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/logon/form-based"}
    :param saml_sp: {"description": "Specify SAML service provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param logout_url: {"description": "Specify logout url (Specify logout url string)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param service_group: {"description": "Bind an authentication service group to this template (Specify authentication service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "server", "type": "string", "$ref": "/axapi/v3/aam/authentication/service-group"}
    :param server: {"description": "Specify authentication server (Specify authentication server template name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "not": "service-group", "type": "string", "$ref": "/axapi/v3/aam/authentication/server/ldap/instance"}
    :param cookie_domain_group: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cookie-dmngrp": {"description": "Specify group id to join in the cookie-domain", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}, "optional": true}}]}
    :param log: {"description": "'use-partition-level-config': Use configuration of authentication-log enable command; 'enable': Enable authentication logs for this template; 'disable': Disable authentication logs for this template; ", "format": "enum", "default": "use-partition-level-config", "type": "string", "enum": ["use-partition-level-config", "enable", "disable"], "optional": true}
    :param account: {"description": "Specify AD domain account", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/aam/authentication/account/kerberos-spn"}
    :param saml_idp: {"description": "Specify SAML identity provider", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param type: {"optional": true, "enum": ["saml", "standard"], "type": "string", "description": "'saml': SAML authentication template; 'standard': Standard authentication template; ", "format": "enum"}
    :param cookie_max_age: {"description": "Configure Max-Age for authentication session cookie (Configure Max-Age in seconds. Default is 604800 (1 week).)", "format": "number", "default": 604800, "optional": true, "maximum": 2592000, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/template/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "template"
        self.a10_url="/axapi/v3/aam/authentication/template/{name}"
        self.DeviceProxy = ""
        self.logout_idle_timeout = ""
        self.cookie_domain = []
        self.name = ""
        self.relay = ""
        self.logon = ""
        self.saml_sp = ""
        self.logout_url = ""
        self.service_group = ""
        self.server = ""
        self.cookie_domain_group = []
        self.log = ""
        self.account = ""
        self.saml_idp = ""
        self.A10WW_type = ""
        self.cookie_max_age = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hits: {"description": "Number of times the site was selected", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.hits = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Site(A10BaseClass):
    
    """Class Description::
    Statistics for the object site.

    Class site supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ip_server_list: {"minItems": 1, "items": {"type": "ip-server"}, "uniqueItems": true, "array": [{"required": ["ip-server-name"], "properties": {"ip-server-name": {"description": "Specify the real server name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}, "stats": {"type": "object", "properties": {"hits": {"description": "Number of times the IP was selected", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}}}}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}"}
    :param site_name: {"description": "Specify GSLB site name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param slb_dev_list: {"minItems": 1, "items": {"type": "slb-dev"}, "uniqueItems": true, "array": [{"required": ["device-name"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/gslb/site/{site-name}/ip-server/{ip-server-name}/active-rdt/easy-rdt/slb-dev/{device-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/site/{site_name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "site_name"]

        self.b_key = "site"
        self.a10_url="/axapi/v3/gslb/site/{site_name}/stats"
        self.DeviceProxy = ""
        self.ip_server_list = []
        self.stats = {}
        self.site_name = ""
        self.slb_dev_list = []
        self.easy_rdt = {}
        self.active_rdt = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_port_up: {"type": "number", "format": "number"}
    :param server_port_down: {"type": "number", "format": "number"}
    :param server_up: {"type": "number", "format": "number"}
    :param server_down: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.server_port_up = ""
        self.server_port_down = ""
        self.server_up = ""
        self.server_down = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HealthCheckSummary(A10BaseClass):
    
    """Class Description::
    Operational Status for the object health-check-summary.

    Class health-check-summary supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/health-check-summary/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "health-check-summary"
        self.a10_url="/axapi/v3/slb/health-check-summary/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Ocsp_Stapling_Requests_to_a10authd: {"description": "Total OCSP Stapling Request", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Open_socket_failed: {"description": "Total AAM Open Socket Failed", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param Ocsp_Stapling_Responses_from_a10authd: {"description": "Total OCSP Stapling Response", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Responses: {"description": "Total Authentication Response", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param Created_timer: {"description": "Total AAM Timer Created", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param Misses: {"description": "Total Authentication Request Missed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Connect_failed: {"description": "Total AAM Connect Failed", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param Opened_socket: {"description": "Total AAM Socket Opened", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param Connect: {"description": "Total AAM Connection", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param Requests: {"description": "Total Authentication Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Total_request: {"description": "Total Request Received by A10 Auth Service", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param Create_timer_failed: {"description": "Total AAM Timer Creation Failed", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Ocsp_Stapling_Requests_to_a10authd = ""
        self.Open_socket_failed = ""
        self.Ocsp_Stapling_Responses_from_a10authd = ""
        self.Responses = ""
        self.Created_timer = ""
        self.Misses = ""
        self.Connect_failed = ""
        self.Opened_socket = ""
        self.Connect = ""
        self.Requests = ""
        self.Total_request = ""
        self.Create_timer_failed = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Global(A10BaseClass):
    
    """Class Description::
    Statistics for the object global.

    Class global supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/global/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "global"
        self.a10_url="/axapi/v3/aam/authentication/global/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ExecBannerCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param exec_banner: {"type": "string", "description": "Banner text", "format": "string-rlx"}
    :param exec: {"default": 0, "type": "number", "description": "Set EXEC process creation banner", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "exec-banner-cfg"
        self.DeviceProxy = ""
        self.exec_banner = ""
        self.A10WW_exec = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LoginBannerCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param login: {"default": 0, "partition-visibility": "shared", "type": "number", "description": "Set login banner", "format": "flag"}
    :param login_banner: {"type": "string", "description": "Banner text", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "login-banner-cfg"
        self.DeviceProxy = ""
        self.login = ""
        self.login_banner = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Banner(A10BaseClass):
    
    """Class Description::
    Define a login banner.

    Class banner supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/banner`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "banner"
        self.a10_url="/axapi/v3/banner"
        self.DeviceProxy = ""
        self.exec_banner_cfg = {}
        self.login_banner_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Tunnel(A10BaseClass):
    
    """Class Description::
    Tunnel interface.

    Class tunnel supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ifnum: {"description": "Tunnel interface number", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": false}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/tunnel/{ifnum}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ifnum"]

        self.b_key = "tunnel"
        self.a10_url="/axapi/v3/interface/tunnel/{ifnum}"
        self.DeviceProxy = ""
        self.ip = {}
        self.ifnum = ""
        self.ipv6 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param conn_rate_limit_drop: {"description": "Conn rate limit drops", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "8"}
    :param outrst_stale_sess: {"description": "TCP out RST stale sess", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param connlimit_reset: {"description": "Conn Limit resets", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "8"}
    :param tcp_sess_aged_out: {"description": "TCP Session aged out", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "8"}
    :param bw_rate_limit_exceed: {"description": "BW-Limit Exceed drop", "format": "counter", "type": "number", "oid": "70", "optional": true, "size": "8"}
    :param no_vport_drop: {"description": "vport not matching drops", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "8"}
    :param snat_icmp_error_process: {"description": "Source NAT ICMP Process", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param port_preserve_attempt: {"description": "NAT Port Preserve Try", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "8"}
    :param anomaly_pbslb_drop: {"description": "Anomaly pbslb drop", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "8"}
    :param proxy_nosock_drop: {"description": "Proxy no sock drops", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "8"}
    :param svr_syn_handshake_fail: {"description": "L4 server handshake fail", "format": "counter", "type": "number", "oid": "79", "optional": true, "size": "8"}
    :param snat_icmp_no_match: {"description": "Source NAT ICMP No Match", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param drop_gslb: {"description": "Drop GSLB", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "8"}
    :param outrst_aflex: {"description": "TCP out RST aFleX", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param anomaly_zero_win: {"description": "Anomaly zero window", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "8"}
    :param concurrent_conn_exceed: {"description": "L3V Conn Limit Drop", "format": "counter", "type": "number", "oid": "78", "optional": true, "size": "8"}
    :param reset_l7_on_failover: {"description": "RST L7 on failover", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "8"}
    :param nosyn_drop_rst: {"description": "No SYN pkt drops - RST", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "8"}
    :param anomaly_bad_content: {"description": "Anomaly bad content", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "8"}
    :param ignore_msl: {"description": "ignore msl", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "8"}
    :param tcpsyndata_drop: {"description": "TCP SYN With Data Drop", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "8"}
    :param nosyn_drop_fin: {"description": "No SYN pkt drops - FIN", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "8"}
    :param anomaly_out_seq: {"description": "Anomaly out of sequence", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "8"}
    :param tcp_rev_ackfin: {"description": "L4 rcv rev FIN|ACK", "format": "counter", "type": "number", "oid": "93", "optional": true, "size": "8"}
    :param tcp_rev_fin: {"description": "L4 rcv rev FIN", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param conn_rate_limit_reset: {"description": "Conn rate limit resets", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "8"}
    :param out_seq_ack_drop: {"description": "Out of sequence ACK drop", "format": "counter", "type": "number", "oid": "103", "optional": true, "size": "8"}
    :param bw_watermark_drop: {"description": "BW-Watermark drop", "format": "counter", "type": "number", "oid": "71", "optional": true, "size": "8"}
    :param sess_aged_out: {"description": "Session aged out", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "8"}
    :param tcp_invalid_drop: {"description": "TCP invalid drop", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "8"}
    :param syn_stale_sess: {"description": "SYN stale sess drop", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param syncookie_buff_drop: {"description": "TCP SYN cookie buff drop", "format": "counter", "type": "number", "oid": "107", "optional": true, "size": "8"}
    :param inudp: {"description": "UDP received", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param tcpotherflags_drop: {"description": "TCP SYN Other Flags Drop", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "8"}
    :param udp_sess_aged_out: {"description": "UDP Session aged out", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "8"}
    :param auto_reassign: {"description": "Auto-reselect server", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "8"}
    :param dns_id_switch: {"description": "DNS query id switch", "format": "counter", "type": "number", "oid": "111", "optional": true, "size": "8"}
    :param fast_aging_set: {"description": "Fast aging set", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "8"}
    :param outrst_ack_attack: {"description": "TCP out RST ACK attack", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param connlimit_drop: {"description": "Conn Limit drops", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "8"}
    :param udp_req_one_oneplus_resp: {"description": "L4 UDP req rsps", "format": "counter", "type": "number", "oid": "97", "optional": true, "size": "8"}
    :param tcp_syn_rcv_rst: {"description": "L4 rcv RST on SYN", "format": "counter", "type": "number", "oid": "83", "optional": true, "size": "8"}
    :param ssl_cps_exceed: {"description": "SSL CPS exceed drop", "format": "counter", "type": "number", "oid": "75", "optional": true, "size": "8"}
    :param syncookiessentfailed: {"description": "TCP SYN cookie snt fail", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param ssl_tpt_exceed: {"description": "SSL TPT exceed drop", "format": "counter", "type": "number", "oid": "76", "optional": true, "size": "8"}
    :param smart_nat_id_mismatch: {"description": "Auto NAT id mismatch", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param tcp_fwd_ackfin: {"description": "L4 rcv fwd FIN|ACK", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param ssl_watermark_drop: {"description": "SSL TPT-Watermark drop", "format": "counter", "type": "number", "oid": "77", "optional": true, "size": "8"}
    :param tcp_rexmit_synack_delq: {"description": "L4 rcv rexmit SYN|ACK DQ", "format": "counter", "type": "number", "oid": "90", "optional": true, "size": "8"}
    :param tcp_fwd_fin: {"description": "L4 rcv fwd FIN", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param tcp_fwd_fin_dup: {"description": "L4 rcv fwd FIN dup", "format": "counter", "type": "number", "oid": "91", "optional": true, "size": "8"}
    :param nosyn_drop_ack: {"description": "No SYN pkt drops - ACK", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "8"}
    :param tcp_rexmit_synack: {"description": "L4 rcv rexmit SYN|ACK", "format": "counter", "type": "number", "oid": "89", "optional": true, "size": "8"}
    :param skip_insert_client_ip: {"description": "Skip Insert-client-ip", "format": "counter", "type": "number", "oid": "109", "optional": true, "size": "8"}
    :param l3_dsr: {"description": "L3 DSR received", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "8"}
    :param tcp_sess_noest_aged_out: {"description": "TCP no-Est Sess aged out", "format": "counter", "type": "number", "oid": "84", "optional": true, "size": "8"}
    :param syn_rate: {"description": "TCP SYN rate per sec", "format": "counter", "type": "number", "oid": "106", "optional": true, "size": "8"}
    :param l7_cps_exceed: {"description": "L7 CPS exceed drop", "format": "counter", "type": "number", "oid": "74", "optional": true, "size": "8"}
    :param synattack: {"description": "L4 SYN attack", "format": "counter", "type": "number", "oid": "105", "optional": true, "size": "8"}
    :param drop_aflex: {"description": "aFleX drops", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "8"}
    :param tcp_est: {"description": "L4 TCP Established", "format": "counter", "type": "number", "oid": "104", "optional": true, "size": "8"}
    :param svrselfail: {"description": "Server sel failure", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param outrst_broker: {"description": "TCP out RST L4 proxy", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param tcp_sess_noest_csyn_rcv_aged_out: {"description": "no-Est CSYN rcv aged out", "format": "counter", "type": "number", "oid": "85", "optional": true, "size": "8"}
    :param novport_drop: {"description": "NAT no session drops", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "8"}
    :param udp_req_oneplus_no_resp: {"description": "L4 UDP reqs no rsp", "format": "counter", "type": "number", "oid": "96", "optional": true, "size": "8"}
    :param fast_aging_reset: {"description": "Fast aging reset", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "8"}
    :param syncookiessent: {"description": "TCP SYN cookie snt", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param tcp_rexmit_syn: {"description": "L4 rcv rexmit SYN", "format": "counter", "type": "number", "oid": "87", "optional": true, "size": "8"}
    :param outrst: {"description": "TCP out RST", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param tcp_ax_rexmit_syn: {"description": "L4 AX re-xmit SYN", "format": "counter", "type": "number", "oid": "81", "optional": true, "size": "8"}
    :param tcp_sess_noest_ssyn_xmit_aged_out: {"description": "no-Est SSYN snt aged out", "format": "counter", "type": "number", "oid": "86", "optional": true, "size": "8"}
    :param syncookie_buff_queue: {"description": "TCP SYN cookie buff queue", "format": "counter", "type": "number", "oid": "108", "optional": true, "size": "8"}
    :param dns_policy_drop: {"description": "DNS Policy Drop", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "8"}
    :param throttle_syn: {"description": "SYN Throttle", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "8"}
    :param nosyn_drop: {"description": "No SYN pkt drops", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "8"}
    :param l4_cps_exceed: {"description": "L4 CPS exceed drop", "format": "counter", "type": "number", "oid": "72", "optional": true, "size": "8"}
    :param tcp_syn_rcv_ack: {"description": "L4 rcv ACK on SYN", "format": "counter", "type": "number", "oid": "82", "optional": true, "size": "8"}
    :param snat_fail: {"description": "Source NAT failure", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param no_resourse_drop: {"description": "No resource drop", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "8"}
    :param inband_hm_retry: {"description": "Inband HM retry", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "8"}
    :param synreceived: {"description": "TCP SYN received", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param reset_unknown_conn: {"description": "Reset unknown conn", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "8"}
    :param l2_dsr: {"description": "L2 DSR received", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "8"}
    :param outrst_nosyn: {"description": "TCP out RST no SYN", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param udp_req_more_resp: {"description": "L4 UDP req greater than rsps", "format": "counter", "type": "number", "oid": "99", "optional": true, "size": "8"}
    :param other_sess_aged_out: {"description": "Other Session aged out", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "8"}
    :param snat_no_rev_route: {"description": "Source NAT no rev route", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param tcp_fwd_rst: {"description": "L4 rcv fwd RST", "format": "counter", "type": "number", "oid": "94", "optional": true, "size": "8"}
    :param tcp_no_slb: {"description": "TCP no SLB", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "8"}
    :param nat_cps_exceed: {"description": "NAT CPS exceed drop", "format": "counter", "type": "number", "oid": "73", "optional": true, "size": "8"}
    :param udp_resp_oneplus: {"description": "L4 UDP rsps", "format": "counter", "type": "number", "oid": "102", "optional": true, "size": "8"}
    :param outrst_tcpproxy: {"description": "TCP out RST TCP proxy", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param tcp_rev_fin_dup: {"description": "L4 rcv rev FIN dup", "format": "counter", "type": "number", "oid": "92", "optional": true, "size": "8"}
    :param udp_req_resp_notmatch: {"description": "L4 UDP req/rsp not match", "format": "counter", "type": "number", "oid": "98", "optional": true, "size": "8"}
    :param udp_no_slb: {"description": "UDP no SLB", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "8"}
    :param port_preserve_succ: {"description": "NAT Port Preserve Succ", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "8"}
    :param udp_resp_more_req: {"description": "L4 UDP rsps greater than reqs", "format": "counter", "type": "number", "oid": "100", "optional": true, "size": "8"}
    :param intcp: {"description": "TCP received", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param tcp_fwd_last_ack: {"description": "L4 rcv fwd last ACK", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param syncookiescheckfailed: {"description": "TCP SYN cookie failed", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "8"}
    :param tcp_rexmit_syn_delq: {"description": "L4 rcv rexmit SYN (delq)", "format": "counter", "type": "number", "oid": "88", "optional": true, "size": "8"}
    :param stateless_conn_timeout: {"description": "L4 stateless Conn TO", "format": "counter", "type": "number", "oid": "80", "optional": true, "size": "8"}
    :param tcp_rev_last_ack: {"description": "L4 rcv rev last ACK", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param tcp_rev_rst: {"description": "L4 rcv rev RST", "format": "counter", "type": "number", "oid": "95", "optional": true, "size": "8"}
    :param noroute: {"description": "IP out noroute", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param udp_req_oneplus: {"description": "L4 UDP reqs", "format": "counter", "type": "number", "oid": "101", "optional": true, "size": "8"}
    :param syncookiessent_ts: {"description": "TCP SYN cookie snt ts", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param snat_no_fwd_route: {"description": "Source NAT no fwd route", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param synreceived_hw: {"description": "TCP SYN (HW SYN cookie)", "format": "counter", "type": "number", "oid": "110", "optional": true, "size": "8"}
    :param inband_hm_reassign: {"description": "Inband HM reassign", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.conn_rate_limit_drop = ""
        self.outrst_stale_sess = ""
        self.connlimit_reset = ""
        self.tcp_sess_aged_out = ""
        self.bw_rate_limit_exceed = ""
        self.no_vport_drop = ""
        self.snat_icmp_error_process = ""
        self.port_preserve_attempt = ""
        self.anomaly_pbslb_drop = ""
        self.proxy_nosock_drop = ""
        self.svr_syn_handshake_fail = ""
        self.snat_icmp_no_match = ""
        self.drop_gslb = ""
        self.outrst_aflex = ""
        self.anomaly_zero_win = ""
        self.concurrent_conn_exceed = ""
        self.reset_l7_on_failover = ""
        self.nosyn_drop_rst = ""
        self.anomaly_bad_content = ""
        self.ignore_msl = ""
        self.tcpsyndata_drop = ""
        self.nosyn_drop_fin = ""
        self.anomaly_out_seq = ""
        self.tcp_rev_ackfin = ""
        self.tcp_rev_fin = ""
        self.conn_rate_limit_reset = ""
        self.out_seq_ack_drop = ""
        self.bw_watermark_drop = ""
        self.sess_aged_out = ""
        self.tcp_invalid_drop = ""
        self.syn_stale_sess = ""
        self.syncookie_buff_drop = ""
        self.inudp = ""
        self.tcpotherflags_drop = ""
        self.udp_sess_aged_out = ""
        self.auto_reassign = ""
        self.dns_id_switch = ""
        self.fast_aging_set = ""
        self.outrst_ack_attack = ""
        self.connlimit_drop = ""
        self.udp_req_one_oneplus_resp = ""
        self.tcp_syn_rcv_rst = ""
        self.ssl_cps_exceed = ""
        self.syncookiessentfailed = ""
        self.ssl_tpt_exceed = ""
        self.smart_nat_id_mismatch = ""
        self.tcp_fwd_ackfin = ""
        self.ssl_watermark_drop = ""
        self.tcp_rexmit_synack_delq = ""
        self.tcp_fwd_fin = ""
        self.tcp_fwd_fin_dup = ""
        self.nosyn_drop_ack = ""
        self.tcp_rexmit_synack = ""
        self.skip_insert_client_ip = ""
        self.l3_dsr = ""
        self.tcp_sess_noest_aged_out = ""
        self.syn_rate = ""
        self.l7_cps_exceed = ""
        self.synattack = ""
        self.drop_aflex = ""
        self.tcp_est = ""
        self.svrselfail = ""
        self.outrst_broker = ""
        self.tcp_sess_noest_csyn_rcv_aged_out = ""
        self.novport_drop = ""
        self.udp_req_oneplus_no_resp = ""
        self.fast_aging_reset = ""
        self.syncookiessent = ""
        self.tcp_rexmit_syn = ""
        self.outrst = ""
        self.tcp_ax_rexmit_syn = ""
        self.tcp_sess_noest_ssyn_xmit_aged_out = ""
        self.syncookie_buff_queue = ""
        self.dns_policy_drop = ""
        self.throttle_syn = ""
        self.nosyn_drop = ""
        self.l4_cps_exceed = ""
        self.tcp_syn_rcv_ack = ""
        self.snat_fail = ""
        self.no_resourse_drop = ""
        self.inband_hm_retry = ""
        self.synreceived = ""
        self.reset_unknown_conn = ""
        self.l2_dsr = ""
        self.outrst_nosyn = ""
        self.udp_req_more_resp = ""
        self.other_sess_aged_out = ""
        self.snat_no_rev_route = ""
        self.tcp_fwd_rst = ""
        self.tcp_no_slb = ""
        self.nat_cps_exceed = ""
        self.udp_resp_oneplus = ""
        self.outrst_tcpproxy = ""
        self.tcp_rev_fin_dup = ""
        self.udp_req_resp_notmatch = ""
        self.udp_no_slb = ""
        self.port_preserve_succ = ""
        self.udp_resp_more_req = ""
        self.intcp = ""
        self.tcp_fwd_last_ack = ""
        self.syncookiescheckfailed = ""
        self.tcp_rexmit_syn_delq = ""
        self.stateless_conn_timeout = ""
        self.tcp_rev_last_ack = ""
        self.tcp_rev_rst = ""
        self.noroute = ""
        self.udp_req_oneplus = ""
        self.syncookiessent_ts = ""
        self.snat_no_fwd_route = ""
        self.synreceived_hw = ""
        self.inband_hm_reassign = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class L4(A10BaseClass):
    
    """Class Description::
    Statistics for the object l4.

    Class l4 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/l4/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "l4"
        self.a10_url="/axapi/v3/slb/l4/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv6Host(A10BaseClass):
    
    """Class Description::
    Specify IPV6 hosts to receive SNMP traps.

    Class ipv6-host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param udp_port: {"description": "The trap host's UDP port number(default: 162)", "format": "number", "default": 162, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param version: {"description": "'v1': Use SNMPv1; 'v2c': Use SNMPv2c; 'v3': User SNMPv3; ", "format": "enum", "default": "v2c", "type": "string", "enum": ["v1", "v2c", "v3"], "optional": false}
    :param ipv6_addr: {"optional": false, "type": "string", "description": "help IPV4 address of SNMP trap host", "format": "ipv6-address"}
    :param user: {"description": "SNMPv3 user to send traps (User Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param v1_v2c_comm: {"description": "SNMPv1/v2c community string", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/host/ipv6-host/{ipv6_addr}+{version}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "ipv6_addr","version"]

        self.b_key = "ipv6-host"
        self.a10_url="/axapi/v3/snmp-server/host/ipv6-host/{ipv6_addr}+{version}"
        self.DeviceProxy = ""
        self.udp_port = ""
        self.version = ""
        self.ipv6_addr = ""
        self.user = ""
        self.v1_v2c_comm = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DistributeLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distribute_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param distribute_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-lists"
        self.DeviceProxy = ""
        self.distribute_list_direction = ""
        self.distribute_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborRouteMapLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nbr_rmap_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param nbr_route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-route-map-lists"
        self.DeviceProxy = ""
        self.nbr_rmap_direction = ""
        self.nbr_route_map = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborFilterLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param filter_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}
    :param filter_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-filter-lists"
        self.DeviceProxy = ""
        self.filter_list = ""
        self.filter_list_direction = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborPrefixLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nbr_prefix_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param nbr_prefix_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-prefix-lists"
        self.DeviceProxy = ""
        self.nbr_prefix_list_direction = ""
        self.nbr_prefix_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4Neighbor(A10BaseClass):
    
    """Class Description::
    Specify a ipv4 neighbor router.

    Class ipv4-neighbor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param timers_holdtime: {"description": "Holdtime", "format": "number", "default": 90, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param activate: {"default": 1, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}
    :param route_refresh: {"default": 1, "optional": true, "type": "number", "description": "Advertise route-refresh capability to this neighbor", "format": "flag"}
    :param ve: {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "trunk"], "type": "number", "description": "Virtual ethernet interface (Virtual ethernet interface number)", "optional": true, "format": "interface"}
    :param weight: {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param timers_keepalive: {"description": "Keepalive interval", "format": "number", "default": 30, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param bfd_value: {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param key_type: {"optional": true, "enum": ["md5", "meticulous-md5", "meticulous-sha1", "sha1", "simple"], "type": "string", "description": "'md5': md5; 'meticulous-md5': meticulous-md5; 'meticulous-sha1': meticulous-sha1; 'sha1': sha1; 'simple': simple;  (Keyed MD5/Meticulous Keyed MD5/Meticulous Keyed SHA1/Keyed SHA1/Simple Password)", "format": "enum"}
    :param dynamic: {"default": 0, "optional": true, "type": "number", "description": "Advertise dynamic capability to this neighbor", "format": "flag"}
    :param loopback: {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "ve", "trunk"], "type": "number", "description": "Loopback interface (Port number)", "optional": true, "format": "interface"}
    :param multihop: {"default": 0, "optional": true, "type": "number", "description": "Enable multihop", "format": "flag"}
    :param default_originate: {"description": "Originate default route to this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}
    :param distribute_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}
    :param shutdown: {"default": 0, "optional": true, "type": "number", "description": "Administratively shut down this neighbor", "format": "flag"}
    :param prefix_list_direction: {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}
    :param as_origination_interval: {"description": "Minimum interval between sending AS-origination routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}
    :param nbr_remote_as: {"description": "Specify AS number of BGP neighbor", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}
    :param advertisement_interval: {"description": "Minimum interval between sending BGP routing updates (time in seconds)", "format": "number", "optional": true, "maximum": 600, "minimum": 1, "not": "peer-group-name", "type": "number"}
    :param lif: {"description": "Logical interface (Lif interface number)", "format": "number", "optional": true, "not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "maximum": 128, "minimum": 1, "type": "number"}
    :param neighbor_route_map_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}
    :param send_community_val: {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}
    :param bfd: {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}
    :param collide_established: {"default": 0, "optional": true, "type": "number", "description": "Include Neighbor in Established State for Collision Detection", "format": "flag"}
    :param next_hop_self: {"description": "Disable the next hop calculation for this neighbor", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}
    :param pass_encrypted: {"optional": true, "type": "encrypted", "format": "encrypted"}
    :param dont_capability_negotiate: {"default": 0, "optional": true, "type": "number", "description": "Do not perform capability negotiation", "format": "flag"}
    :param unsuppress_map: {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "peer-group-name", "type": "string"}
    :param passive: {"default": 0, "optional": true, "type": "number", "description": "Don't send open messages to this neighbor", "format": "flag"}
    :param ebgp_multihop_hop_count: {"description": "maximum hop count", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}
    :param allowas_in: {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}
    :param pass_value: {"description": "Key String", "format": "password", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param key_id: {"description": "Key ID", "format": "number", "type": "number", "maximum": 255, "minimum": 0, "optional": true}
    :param connection_retry_time: {"description": "BGP per neighbor timers (BGP connect timer)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param update_source_ip: {"not-list": ["update-source-ipv6", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IP address", "optional": true, "format": "ipv4-address"}
    :param description: {"optional": true, "type": "string", "description": "Neighbor specific description (Up to 80 characters describing this neighbor)", "format": "string-rlx"}
    :param neighbor_ipv4: {"optional": false, "type": "string", "description": "Neighbor address", "format": "ipv4-address"}
    :param inbound: {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}
    :param maximum_prefix_thres: {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param bfd_encrypted: {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param disallow_infinite_holdtime: {"description": "BGP per neighbor disallow-infinite-holdtime", "format": "flag", "default": 0, "optional": true, "not": "peer-group-name", "type": "number"}
    :param trunk: {"not-list": ["update-source-ip", "update-source-ipv6", "ethernet", "loopback", "ve"], "type": "number", "description": "Trunk interface (Trunk interface number)", "optional": true, "format": "interface"}
    :param remove_private_as: {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}
    :param neighbor_filter_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}
    :param update_source_ipv6: {"not-list": ["update-source-ip", "ethernet", "loopback", "ve", "trunk"], "type": "string", "description": "IPv6 address", "optional": true, "format": "ipv6-address"}
    :param maximum_prefix: {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}
    :param neighbor_prefix_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}
    :param allowas_in_count: {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param peer_group_name: {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "not-list": ["advertisement-interval", "as-origination-interval", "default-originate", "disallow-infinite-holdtime", "next-hop-self", "timers", "unsuppress-map"], "optional": true, "maxLength": 128, "type": "string"}
    :param enforce_multihop: {"default": 0, "optional": true, "type": "number", "description": "Enforce EBGP neighbors to perform multihop", "format": "flag"}
    :param override_capability: {"default": 0, "optional": true, "type": "number", "description": "Override capability negotiation result", "format": "flag"}
    :param route_map: {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param strict_capability_match: {"default": 0, "optional": true, "type": "number", "description": "Strict capability negotiation match", "format": "flag"}
    :param ebgp_multihop: {"default": 0, "optional": true, "type": "number", "description": "Allow EBGP neighbors not on directly connected networks", "format": "flag"}
    :param ethernet: {"not-list": ["update-source-ip", "update-source-ipv6", "loopback", "ve", "trunk"], "type": "number", "description": "Ethernet interface (Port number)", "optional": true, "format": "interface"}
    :param connect: {"description": "BGP connect timer", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/neighbor/ipv4-neighbor/{neighbor_ipv4}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "neighbor_ipv4"]

        self.b_key = "ipv4-neighbor"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/neighbor/ipv4-neighbor/{neighbor_ipv4}"
        self.DeviceProxy = ""
        self.timers_holdtime = ""
        self.activate = ""
        self.route_refresh = ""
        self.ve = ""
        self.weight = ""
        self.timers_keepalive = ""
        self.bfd_value = ""
        self.key_type = ""
        self.dynamic = ""
        self.loopback = ""
        self.multihop = ""
        self.default_originate = ""
        self.distribute_lists = []
        self.shutdown = ""
        self.prefix_list_direction = ""
        self.as_origination_interval = ""
        self.nbr_remote_as = ""
        self.advertisement_interval = ""
        self.lif = ""
        self.neighbor_route_map_lists = []
        self.send_community_val = ""
        self.bfd = ""
        self.collide_established = ""
        self.next_hop_self = ""
        self.pass_encrypted = ""
        self.dont_capability_negotiate = ""
        self.unsuppress_map = ""
        self.passive = ""
        self.ebgp_multihop_hop_count = ""
        self.allowas_in = ""
        self.pass_value = ""
        self.key_id = ""
        self.connection_retry_time = ""
        self.update_source_ip = ""
        self.description = ""
        self.neighbor_ipv4 = ""
        self.inbound = ""
        self.maximum_prefix_thres = ""
        self.bfd_encrypted = ""
        self.disallow_infinite_holdtime = ""
        self.trunk = ""
        self.remove_private_as = ""
        self.neighbor_filter_lists = []
        self.update_source_ipv6 = ""
        self.maximum_prefix = ""
        self.neighbor_prefix_lists = []
        self.allowas_in_count = ""
        self.peer_group_name = ""
        self.enforce_multihop = ""
        self.override_capability = ""
        self.route_map = ""
        self.strict_capability_match = ""
        self.ebgp_multihop = ""
        self.ethernet = ""
        self.connect = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RequireAssertionSigned(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param require_assertion_signed_enable: {"default": 0, "type": "number", "description": "Enable required signing of SAML assertion", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "require-assertion-signed"
        self.DeviceProxy = ""
        self.require_assertion_signed_enable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SingleLogoutService(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param SLO_binding: {"enum": ["post", "redirect", "soap"], "type": "string", "description": "'post': POST binding of single logout service; 'redirect': Redirect binding of single logout service; 'soap': SOAP binding of single logout service; ", "format": "enum"}
    :param SLO_location: {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of name-id management service. (ex. /SAML/POST)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "single-logout-service"
        self.DeviceProxy = ""
        self.SLO_binding = ""
        self.SLO_location = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AssertionConsumingService(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param assertion_index: {"description": "The index of assertion consuming service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}
    :param assertion_binding: {"enum": ["artifact", "paos", "post"], "type": "string", "description": "'artifact': Artifact binding of assertion consuming service; 'paos': PAOS binding of assertion consuming service; 'post': POST binding of assertion consuming service; ", "format": "enum"}
    :param assertion_location: {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of assertion consuming service endpoint. (ex. /SAML/POST)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "assertion-consuming-service"
        self.DeviceProxy = ""
        self.assertion_index = ""
        self.assertion_binding = ""
        self.assertion_location = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SamlRequestSigned(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param saml_request_signed_disable: {"default": 0, "type": "number", "description": "Disable signing signature for SAML (Authn/Artifact Resolve) requests", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "saml-request-signed"
        self.DeviceProxy = ""
        self.saml_request_signed_disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SoapTlsCertificateValidate(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param soap_tls_certificate_validate_disable: {"default": 0, "type": "number", "description": "Disable verification for server certificate in TLS session when resolving artificate", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "soap-tls-certificate-validate"
        self.DeviceProxy = ""
        self.soap_tls_certificate_validate_disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ArtifactResolutionService(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param artifact_location: {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of artifact resolution service. (ex. /SAML/POST)", "format": "string-rlx"}
    :param artifact_binding: {"enum": ["soap"], "type": "string", "description": "'soap': SOAP binding of artifact resolution service; ", "format": "enum"}
    :param artifact_index: {"description": "The index of artifact resolution service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "artifact-resolution-service"
        self.DeviceProxy = ""
        self.artifact_location = ""
        self.artifact_binding = ""
        self.artifact_index = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MetadataExportService(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param md_export_location: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the URI to export SP metadata (Export URI. Default is /A10SP_Metadata)", "format": "string-rlx"}
    :param sign_xml: {"default": 0, "type": "number", "description": "Sign exported SP metadata XML with SP's certificate", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "metadata-export-service"
        self.DeviceProxy = ""
        self.md_export_location = ""
        self.sign_xml = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class ServiceProvider(A10BaseClass):
    
    """Class Description::
    Authentication service provider.

    Class service-provider supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify SAML authentication service provider name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param certificate: {"description": "SAML service provider certificate file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param single_logout_service: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "SLO-binding": {"enum": ["post", "redirect", "soap"], "type": "string", "description": "'post': POST binding of single logout service; 'redirect': Redirect binding of single logout service; 'soap': SOAP binding of single logout service; ", "format": "enum"}, "SLO-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of name-id management service. (ex. /SAML/POST)", "format": "string-rlx"}}}]}
    :param service_url: {"description": "SAML service provider service URL (ex. https://www.a10networks.com/saml.sso)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param entity_id: {"description": "SAML service provider entity ID", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param assertion_consuming_service: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "assertion-index": {"description": "The index of assertion consuming service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}, "assertion-binding": {"enum": ["artifact", "paos", "post"], "type": "string", "description": "'artifact': Artifact binding of assertion consuming service; 'paos': PAOS binding of assertion consuming service; 'post': POST binding of assertion consuming service; ", "format": "enum"}, "assertion-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of assertion consuming service endpoint. (ex. /SAML/POST)", "format": "string-rlx"}}}]}
    :param artifact_resolution_service: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"artifact-location": {"minLength": 1, "maxLength": 63, "type": "string", "description": "The location of artifact resolution service. (ex. /SAML/POST)", "format": "string-rlx"}, "optional": true, "artifact-binding": {"enum": ["soap"], "type": "string", "description": "'soap': SOAP binding of artifact resolution service; ", "format": "enum"}, "artifact-index": {"description": "The index of artifact resolution service", "minimum": 0, "type": "number", "maximum": 5, "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/saml/service-provider/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "service-provider"
        self.a10_url="/axapi/v3/aam/authentication/saml/service-provider/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.certificate = ""
        self.require_assertion_signed = {}
        self.single_logout_service = []
        self.service_url = ""
        self.entity_id = ""
        self.assertion_consuming_service = []
        self.saml_request_signed = {}
        self.soap_tls_certificate_validate = {}
        self.artifact_resolution_service = []
        self.metadata_export_service = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SourceInterface(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param loopback: {"type": "number", "description": "Loopback interface (Port number)", "format": "interface"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "source-interface"
        self.DeviceProxy = ""
        self.loopback = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MgmtTraffic(A10BaseClass):
    
    """Class Description::
    Management traffic IP parameters.

    Class mgmt-traffic supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param traffic_type: {"optional": false, "enum": ["all", "ftp", "ntp", "rcp", "snmp", "ssh", "syslog", "telnet", "tftp", "web"], "type": "string", "description": "'all': All; 'ftp': FTP; 'ntp': NTP; 'rcp': RCP; 'snmp': SNMP; 'ssh': SSH and SCP; 'syslog': SYSLOG; 'telnet': Telnet; 'tftp': TFTP; 'web': Web - HTTP and HTTPS; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/mgmt-traffic/{traffic_type}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "traffic_type"]

        self.b_key = "mgmt-traffic"
        self.a10_url="/axapi/v3/ip/mgmt-traffic/{traffic_type}"
        self.DeviceProxy = ""
        self.traffic_type = ""
        self.source_interface = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BfdIpv6(A10BaseClass):
    
    """Class Description::
    Bidirectional Forwarding Detection.

    Class bfd-ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param local_ipv6: {"optional": false, "type": "string", "description": "Local IPv6 address", "format": "ipv6-address"}
    :param nexthop_ipv6: {"optional": false, "type": "string", "description": "Nexthop IPv6 address", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ipv6/route/static/bfd/bfd-ipv6/{local_ipv6}+{nexthop_ipv6}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "local_ipv6","nexthop_ipv6"]

        self.b_key = "bfd-ipv6"
        self.a10_url="/axapi/v3/ipv6/route/static/bfd/bfd-ipv6/{local_ipv6}+{nexthop_ipv6}"
        self.DeviceProxy = ""
        self.local_ipv6 = ""
        self.nexthop_ipv6 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_mapping_nat64_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "17", "format": "counter"}
    :param netflow_v5_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "21", "format": "counter"}
    :param port_mapping_nat44_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "16", "format": "counter"}
    :param session_event_nat64_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "11", "format": "counter"}
    :param netflow_v5_ext_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "24", "format": "counter"}
    :param port_mapping_dslite_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "20", "format": "counter"}
    :param session_event_dslite_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "13", "format": "counter"}
    :param netflow_v5_ext_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "23", "format": "counter"}
    :param dslite_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "8", "format": "counter"}
    :param session_event_nat44_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "9", "format": "counter"}
    :param port_mapping_nat64_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "18", "format": "counter"}
    :param nat64_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "5", "format": "counter"}
    :param port_mapping_dslite_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "19", "format": "counter"}
    :param bytes_sent: {"optional": true, "size": "8", "type": "number", "oid": "2", "format": "counter"}
    :param session_event_dslite_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "14", "format": "counter"}
    :param nat44_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "4", "format": "counter"}
    :param dslite_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "7", "format": "counter"}
    :param port_mapping_nat44_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "15", "format": "counter"}
    :param session_event_nat44_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "10", "format": "counter"}
    :param session_event_nat64_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "12", "format": "counter"}
    :param nat44_records_sent: {"optional": true, "size": "8", "type": "number", "oid": "3", "format": "counter"}
    :param packets_sent: {"optional": true, "size": "8", "type": "number", "oid": "1", "format": "counter"}
    :param nat64_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "6", "format": "counter"}
    :param netflow_v5_records_sent_failure: {"optional": true, "size": "8", "type": "number", "oid": "22", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.port_mapping_nat64_records_sent = ""
        self.netflow_v5_records_sent = ""
        self.port_mapping_nat44_records_sent_failure = ""
        self.session_event_nat64_records_sent = ""
        self.netflow_v5_ext_records_sent_failure = ""
        self.port_mapping_dslite_records_sent_failure = ""
        self.session_event_dslite_records_sent = ""
        self.netflow_v5_ext_records_sent = ""
        self.dslite_records_sent_failure = ""
        self.session_event_nat44_records_sent = ""
        self.port_mapping_nat64_records_sent_failure = ""
        self.nat64_records_sent = ""
        self.port_mapping_dslite_records_sent = ""
        self.bytes_sent = ""
        self.session_event_dslite_records_sent_failure = ""
        self.nat44_records_sent_failure = ""
        self.dslite_records_sent = ""
        self.port_mapping_nat44_records_sent = ""
        self.session_event_nat44_records_sent_failure = ""
        self.session_event_nat64_records_sent_failure = ""
        self.nat44_records_sent = ""
        self.packets_sent = ""
        self.nat64_records_sent_failure = ""
        self.netflow_v5_records_sent_failure = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Monitor(A10BaseClass):
    
    """Class Description::
    Statistics for the object monitor.

    Class monitor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Name of netflow monitor", "format": "string-rlx", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/netflow/monitor/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "monitor"
        self.a10_url="/axapi/v3/netflow/monitor/{name}/stats"
        self.DeviceProxy = ""
        self.resend_template = {}
        self.stats = {}
        self.name = ""
        self.source_address = {}
        self.destination = {}
        self.sample = {}
        self.record = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ServiceGroup(A10BaseClass):
    
    """Class Description::
    Service Group.

    Class service-group supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param shared_partition: {"description": "Share with a single partition (Partition Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": true, "maxLength": 14, "type": "string"}
    :param protocol: {"description": "'tcp': TCP LB service; 'udp': UDP LB service; ", "format": "enum", "type": "string", "enum": ["tcp", "udp"], "modify-not-allowed": 1, "optional": true}
    :param name: {"description": "CGNV6 Service Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param health_check: {"description": "Health Check (Monitor Name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param member_list: {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["name", "port"], "properties": {"name": {"description": "Member name", "format": "comp-string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string", "$ref": "/axapi/v3/cgnv6/server"}, "port": {"description": "Port number", "format": "number", "default": 65534, "optional": false, "maximum": 65534, "minimum": 0, "type": "number", "$ref": "/axapi/v3/cgnv6/server/port"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/service-group/{name}/member/{name}+{port}"}
    :param shared_group: {"description": "Share with a partition group (Partition Group Name)", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/service-group/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "service-group"
        self.a10_url="/axapi/v3/cgnv6/service-group/{name}"
        self.DeviceProxy = ""
        self.shared_partition = ""
        self.protocol = ""
        self.name = ""
        self.health_check = ""
        self.member_list = []
        self.shared_group = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Host(A10BaseClass):
    
    """Class Description::
    Configure license manager host.

    Class host supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param host_ipv4: {"description": "license server ip address (length:1-31)", "format": "host", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}
    :param port: {"description": "Configure the license manager port, default is 443", "format": "number", "default": 443, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/license-manager/host/{host_ipv4}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "host_ipv4"]

        self.b_key = "host"
        self.a10_url="/axapi/v3/license-manager/host/{host_ipv4}"
        self.DeviceProxy = ""
        self.host_ipv4 = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeolocRdtList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param rdt: {"type": "number", "format": "number"}
    :param site_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param gl_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param age: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geoloc-rdt-list"
        self.DeviceProxy = ""
        self.rdt = ""
        self.site_name = ""
        self.gl_name = ""
        self.A10WW_type = ""
        self.age = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geoloc_rdt_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"rdt": {"type": "number", "format": "number"}, "optional": true, "site-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "gl-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "age": {"type": "number", "format": "number"}}}]}
    :param geo_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param site_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param active_status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param total_rdt: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.geoloc_rdt_list = []
        self.geo_name = ""
        self.site_name = ""
        self.active_status = ""
        self.total_rdt = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GeolocRdt(A10BaseClass):
    
    """Class Description::
    Operational Status for the object geoloc-rdt.

    Class geoloc-rdt supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/geoloc-rdt/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "geoloc-rdt"
        self.a10_url="/axapi/v3/gslb/geoloc-rdt/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ipv6(A10BaseClass):
    
    """Class Description::
    Configure sFlow IPv6 collector.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param addr: {"optional": false, "type": "string", "description": "Configure sFlow collector IPv6 address", "format": "ipv6-address"}
    :param port: {"description": "Port number (default is 6343)", "format": "number", "default": 6343, "optional": false, "maximum": 65535, "minimum": 1, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/sflow/collector/ipv6/{addr}+{port}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "addr","port"]

        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/sflow/collector/ipv6/{addr}+{port}"
        self.DeviceProxy = ""
        self.addr = ""
        self.port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class OverlayTunnel(A10BaseClass):
    
    """Class Description::
    Configure a Tunnel end point.

    Class overlay-tunnel supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vtep_list: {"minItems": 1, "items": {"type": "vtep"}, "uniqueItems": true, "array": [{"required": ["id"], "properties": {"host-list": {"minItems": 1, "items": {"type": "host"}, "uniqueItems": true, "array": [{"required": ["ip-addr", "overlay-mac-addr", "vni", "destination-vtep"], "properties": {"destination-vtep": {"optional": false, "type": "string", "description": "Configure the VTEP IP address (IPv4 address of the VTEP for the remote host)", "format": "ipv4-address"}, "ip-addr": {"optional": false, "type": "string", "description": "IPv4 address of the overlay host", "format": "ipv4-address"}, "vni": {"description": " Configure the segment id ( VNI of the remote host)", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}, "overlay-mac-addr": {"optional": false, "type": "string", "description": "MAC Address of the overlay host", "format": "mac-address"}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/host/{ip-addr}+{overlay-mac-addr}+{vni}+{destination-vtep}"}, "destination-ip-address-list": {"minItems": 1, "items": {"type": "destination-ip-address"}, "uniqueItems": true, "array": [{"required": ["ip-address"], "properties": {"vni-list": {"minItems": 1, "items": {"type": "vni"}, "uniqueItems": true, "array": [{"required": ["segment"], "properties": {"segment": {"description": "VNI configured for the remote VTEP", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/destination-ip-address/{ip-address}/vni/{segment}"}, "encap": {"optional": true, "enum": ["nvgre", "vxlan"], "type": "string", "description": "'nvgre': Tunnel Encapsulation Type is NVGRE; 'vxlan': Tunnel Encapsulation Type is NVGRE; ", "format": "enum"}, "ip-address": {"optional": false, "type": "string", "description": "IP Address of the remote VTEP", "format": "ipv4-address"}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/destination-ip-address/{ip-address}"}, "id": {"description": "VTEP Identifier", "format": "number", "type": "number", "maximum": 64, "minimum": 1, "optional": false}, "encap": {"description": "'nvgre': Tunnel Encapsulation Type is NVGRE; 'vxlan': Tunnel Encapsulation Type is NVGRE; ", "format": "enum", "default": "vxlan", "type": "string", "enum": ["nvgre", "vxlan"], "optional": true}, "source-ip-address": {"type": "object", "properties": {"vni-list": {"minItems": 1, "items": {"type": "vni"}, "uniqueItems": true, "array": [{"required": ["segment"], "properties": {"lif": {"description": "Logical interface binding the Provider Partition to the User Partition (logical interface number)", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": true}, "partition": {"description": "Name of the Partition with the L2 segment being extended (Name of the User Partition with the L2 segment being extended)", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "segment": {"description": "Id of the segment that is being extended", "format": "number", "type": "number", "maximum": 16777215, "minimum": 1, "optional": false}, "gateway": {"default": 0, "optional": true, "type": "number", "description": "This is a Gateway segment id", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}/source-ip-address/vni/{segment}"}, "ip-address": {"type": "string", "description": "Source Tunnel End Point IPv4 address", "format": "ipv4-address"}}}}}], "type": "array", "$ref": "/axapi/v3/overlay-tunnel/vtep/{id}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/overlay-tunnel`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "overlay-tunnel"
        self.a10_url="/axapi/v3/overlay-tunnel"
        self.DeviceProxy = ""
        self.options = {}
        self.vtep_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Debug(A10BaseClass):
    
    """    :param info: {"default": 0, "optional": true, "type": "number", "description": "Information component", "format": "flag"}
    :param daemon: {"default": 0, "optional": true, "type": "number", "description": "Daemon component", "format": "flag"}
    :param vblade: {"default": 0, "optional": true, "type": "number", "description": "vBlade component", "format": "flag"}
    :param election: {"default": 0, "optional": true, "type": "number", "description": "Election component", "format": "flag"}
    :param vmaster: {"default": 0, "optional": true, "type": "number", "description": "vMaster component", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    VCS debug.

    Class debug supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vcs/debug`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "debug"
        self.a10_url="/axapi/v3/vcs/debug"
        self.DeviceProxy = ""
        self.info = ""
        self.daemon = ""
        self.vblade = ""
        self.election = ""
        self.vmaster = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AuthSamlIdp(A10BaseClass):
    
    """    :param saml_idp_name: {"description": "Local IDP metadata name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    SAML metadata of identity provider.

    Class auth-saml-idp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/delete/auth-saml-idp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "auth-saml-idp"
        self.a10_url="/axapi/v3/delete/auth-saml-idp"
        self.DeviceProxy = ""
        self.saml_idp_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SnmpServer(A10BaseClass):
    
    """Class Description::
    Configure SNMP engine parameters.

    Class snmp-server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param view_list: {"minItems": 1, "items": {"type": "view"}, "uniqueItems": true, "array": [{"required": ["viewname", "oid"], "properties": {"mask": {"description": "Hex octets, separated by '.', mask of oid", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "type", "type": "string"}, "oid": {"description": "MIB view family name or oid", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "type": {"description": "'included': MIB family is included in the view; 'excluded': MIB family is excluded from the view; ", "format": "enum", "type": "string", "enum": ["included", "excluded"], "not": "mask", "optional": true}, "viewname": {"description": "Name of the view", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/view/{viewname}+{oid}"}
    :param group_list: {"minItems": 1, "items": {"type": "group"}, "uniqueItems": true, "array": [{"required": ["groupname"], "properties": {"read": {"description": "specify a read view for the group (read view name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "groupname": {"description": "Name of the group", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "v3": {"optional": true, "enum": ["auth", "noauth", "priv"], "type": "string", "description": "'auth': group using the authNoPriv Security Level; 'noauth': group using the noAuthNoPriv Security Level; 'priv': group using SNMPv3 authPriv security level; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/group/{groupname}"}
    :param user_list: {"minItems": 1, "items": {"type": "user"}, "uniqueItems": true, "array": [{"required": ["username"], "properties": {"username": {"description": "Name of the user", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "auth-val": {"optional": true, "enum": ["md5", "sha"], "type": "string", "description": "'md5': Use HMAC MD5 algorithm for authentication; 'sha': Use HMAC SHA algorithm for authentication; ", "format": "enum"}, "group": {"description": "Group to which the user belongs", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "encpasswd": {"description": "Passphrase for encryption", "format": "password", "minLength": 8, "optional": true, "maxLength": 31, "type": "string"}, "passwd": {"description": "Password of this user", "format": "password", "minLength": 8, "optional": true, "maxLength": 31, "type": "string"}, "priv-pw-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED passphrase string)", "format": "encrypted"}, "v3": {"optional": true, "enum": ["auth", "noauth"], "type": "string", "description": "'auth': Using the authNoPriv Security Level; 'noauth': Using the noAuthNoPriv Security Level; ", "format": "enum"}, "pw-encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED passphrase string)", "format": "encrypted"}, "priv": {"optional": true, "enum": ["des", "aes"], "type": "string", "description": "'des': DES encryption alogrithm; 'aes': AES encryption alogrithm;  (Encryption type)", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/snmp-server/user/{username}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "snmp-server"
        self.a10_url="/axapi/v3/snmp-server"
        self.DeviceProxy = ""
        self.enable = {}
        self.slb_data_cache_timeout = {}
        self.view_list = []
        self.community = {}
        self.contact = {}
        self.host = {}
        self.disable = {}
        self.location = {}
        self.group_list = []
        self.user_list = []
        self.engineID = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GslbLoadFileList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param geo_location_load_filename: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify file to be loaded", "format": "string-rlx"}
    :param template_name: {"description": "CSV template to load this file", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/template/csv"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "gslb-load-file-list"
        self.DeviceProxy = ""
        self.geo_location_load_filename = ""
        self.template_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class System(A10BaseClass):
    
    """Class Description::
    GSLB system options.

    Class system supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param gslb_service_ip: {"default": 0, "optional": true, "type": "number", "description": "GSLB Service-IP", "format": "flag"}
    :param gslb_site: {"default": 0, "optional": true, "type": "number", "description": "GSLB Site", "format": "flag"}
    :param ip_ttl: {"description": "TTL of IP packets, default is 0 (IP TTL value, default is 0)", "format": "number", "default": 0, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}
    :param gslb_group: {"default": 0, "optional": true, "type": "number", "description": "GSLB Group", "format": "flag"}
    :param slb_device: {"default": 0, "optional": true, "type": "number", "description": "SLB Device", "format": "flag"}
    :param hostname: {"default": 0, "optional": true, "type": "number", "description": "System's Network Name", "format": "flag"}
    :param module: {"default": 0, "optional": true, "type": "number", "description": "Specify Auto Map Module", "format": "flag"}
    :param age_interval: {"description": "Interval to age runtime statistics. 0: never age, default is 10 (Time, unit: sec, default is 10)", "format": "number", "default": 10, "optional": true, "maximum": 120, "minimum": 0, "type": "number"}
    :param geo_location_iana: {"default": 1, "optional": true, "type": "number", "description": "Load built-in IANA table", "format": "flag"}
    :param ttl: {"description": "Specify Auto Map TTL (TTL, default is 300)", "format": "number", "default": 300, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param slb_server: {"default": 0, "optional": true, "type": "number", "description": "SLB Server", "format": "flag"}
    :param slb_virtual_server: {"default": 0, "optional": true, "type": "number", "description": "SLB Virtual Server", "format": "flag"}
    :param gslb_load_file_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "geo-location-load-filename": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify file to be loaded", "format": "string-rlx"}, "template-name": {"description": "CSV template to load this file", "format": "string", "minLength": 1, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/gslb/template/csv"}}}]}
    :param wait: {"description": "Disable GSLB until timeout if system is not ready (Time, unit: sec, default is 0)", "format": "number", "default": 0, "optional": true, "maximum": 16384, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/system`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "system"
        self.a10_url="/axapi/v3/gslb/system"
        self.DeviceProxy = ""
        self.gslb_service_ip = ""
        self.gslb_site = ""
        self.ip_ttl = ""
        self.gslb_group = ""
        self.slb_device = ""
        self.hostname = ""
        self.module = ""
        self.age_interval = ""
        self.geo_location_iana = ""
        self.ttl = ""
        self.slb_server = ""
        self.slb_virtual_server = ""
        self.gslb_load_file_list = []
        self.wait = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class FanSpeed(A10BaseClass):
    
    """Class Description::
    Control FAN Speed setting.

    Class fan-speed supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param action: {"description": "'auto': Set FAN Speed to automatic based on system temperature; 'max': Set FAN Speed to maximum; ", "format": "enum", "default": "auto", "type": "string", "enum": ["auto", "max"], "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/fan-speed`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "fan-speed"
        self.a10_url="/axapi/v3/fan-speed"
        self.DeviceProxy = ""
        self.action = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


